@@ -31,7 +31,7 @@
 
 #include "print.h"
 
-#ifndef HAVE_R
+#ifndef USING_R
 void nifti_swap_8bytes( size_t n , void *ar )    // 4 bytes at a time
 {
     size_t ii ;
@@ -86,19 +86,19 @@ int isSameFloat (float a, float b) {
 
 ivec3 setiVec3(int x, int y, int z)
 {
-    ivec3 v = {x, y, z};
+    ivec3 v = {{x, y, z}};
     return v;
 }
 
 vec3 setVec3(float x, float y, float z)
 {
-    vec3 v = {x, y, z};
+    vec3 v = {{x, y, z}};
     return v;
 }
 
 vec4 setVec4(float x, float y, float z)
 {
-    vec4 v= {x, y, z, 1};
+    vec4 v= {{x, y, z, 1}};
     return v;
 }
 
@@ -188,7 +188,7 @@ mat44 nifti_dicom2mat(float orient[7], float patientPosition[4], float xyzMM[4])
     return Q44;
 }
 
-#ifndef HAVE_R
+#ifndef USING_R
 float nifti_mat33_determ( mat33 R )   /* determinant of 3x3 matrix */
 {
     double r11,r12,r13,r21,r22,r23,r31,r32,r33 ;
@@ -235,7 +235,7 @@ mat33 nifti_mat33_transpose( mat33 A )  /* transpose 3x3 matrix */
     return B;
 }
 
-#ifndef HAVE_R
+#ifndef USING_R
 mat33 nifti_mat33_inverse( mat33 R )   /* inverse of 3x3 matrix */
 {
     double r11,r12,r13,r21,r22,r23,r31,r32,r33 , deti ;
